@@ -26,9 +26,9 @@ class ReadingIO:
     def read_bytes(self, n) -> bytes:
         data = self.buff.read(n)
         if not data:
-            raise NoData(f"No data. Expected {n} bytes", expected_bytes=n, got_bytes=0)
+            raise NoData(n, 0, f"No data. Expected {n} bytes")
         if len(data) != n:
-            raise NoData(f"Not enough data. Expected {n} bytes got {len(data)}", expected_bytes=n, got_bytes=len(data))
+            raise NoData(n, len(data), f"Not enough data. Expected {n} bytes got {len(data)}")
 
         return data
 
@@ -131,7 +131,8 @@ class WritingIO:
         self.write_bytes(b'\x00')
 
     def flush(self):
-        self.buff.flush()
+        if hasattr(self.buff, 'flush'):
+            self.buff.flush()
 
     def close(self):
         self.buff.close()
